<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Unable to get exclusive lock</source>
        <translation>No se pudo obtener el bloqueo exclusivo</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>Another package management application (like Synaptic or apt-get), is already running. Please close that application first</source>
        <translation>Otra aplicación de manejo de paquetes (como Synaptic o apt-get) ya está ejecutándose. Por favor cierre dicha aplicación primero. </translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>You must run this program as root.</source>
        <translation>Debe ejecutar este programa como root.</translation>
    </message>
</context>
<context>
    <name>mxcodecs</name>
    <message>
        <location filename="../mxcodecs.ui" line="14"/>
        <source>MX Codecs Installer</source>
        <translation>MX Codecs Installer</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="27"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;This application allows you to install restricted codecs that permit advanced video and audio functions.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;In some juridictions their distribution may be limited so the user must meet local regulations. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Do you assume legal responsibility for downloading these codecs?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;Esta aplicación le permite instalar códecs restringidos que permiten funciones avanzadas de audio y video.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;En ciertas jurisdicciones, su distribución puede hallarse limitada para que los usuarios se ajusten a regulaciones locales. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;¿Asume la responsabilidad legar por descargar estos códecs?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="44"/>
        <source>Downloading codecs files</source>
        <translation>Descargando los archivos códec</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="94"/>
        <source>Cancel any changes then quit</source>
        <translation>Cancelar los cambios y luego salir</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="97"/>
        <location filename="../mxcodecs.cpp" line="267"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="105"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="118"/>
        <source>Apply any changes then quit</source>
        <translation>Aplicar los cambios y salir</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="121"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="177"/>
        <source>About this application</source>
        <translation>Acerca de esta aplicación</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="180"/>
        <source>About...</source>
        <translation>Acerca de...</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="188"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="217"/>
        <source>Display help </source>
        <translation>Mostrar la ayuda</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="220"/>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="228"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="104"/>
        <location filename="../mxcodecs.cpp" line="111"/>
        <location filename="../mxcodecs.cpp" line="119"/>
        <location filename="../mxcodecs.cpp" line="127"/>
        <location filename="../mxcodecs.cpp" line="136"/>
        <location filename="../mxcodecs.cpp" line="143"/>
        <location filename="../mxcodecs.cpp" line="152"/>
        <location filename="../mxcodecs.cpp" line="160"/>
        <source>&lt;b&gt;Running command...&lt;/b&gt;&lt;p&gt;</source>
        <translation>&lt;b&gt;Ejecutando la orden...&lt;/b&gt;&lt;p&gt;</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="107"/>
        <location filename="../mxcodecs.cpp" line="123"/>
        <location filename="../mxcodecs.cpp" line="130"/>
        <location filename="../mxcodecs.cpp" line="139"/>
        <location filename="../mxcodecs.cpp" line="145"/>
        <location filename="../mxcodecs.cpp" line="156"/>
        <location filename="../mxcodecs.cpp" line="163"/>
        <location filename="../mxcodecs.cpp" line="192"/>
        <location filename="../mxcodecs.cpp" line="245"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="108"/>
        <location filename="../mxcodecs.cpp" line="124"/>
        <location filename="../mxcodecs.cpp" line="140"/>
        <location filename="../mxcodecs.cpp" line="157"/>
        <source>Cannot connect to the download site</source>
        <translation>No es posible conectarse al sitio de descargas</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="114"/>
        <location filename="../mxcodecs.cpp" line="131"/>
        <location filename="../mxcodecs.cpp" line="146"/>
        <location filename="../mxcodecs.cpp" line="164"/>
        <source>Error downloading %1</source>
        <translation>Error al descargar %1</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="169"/>
        <source>&lt;b&gt;Download Finished.&lt;/b&gt;</source>
        <translation>&lt;b&gt;Descarga finalizada.&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="188"/>
        <source>Installing downloaded files</source>
        <translation>Instalando los archivos descargados</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="193"/>
        <source>No downloaded *.debs files found.</source>
        <translation>No se encontraron archivos *.debs descargados</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="206"/>
        <source>&lt;b&gt;Installing...&lt;/b&gt;&lt;p&gt;</source>
        <translation>&lt;b&gt;Instalando...&lt;/b&gt;&lt;p&gt;</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="219"/>
        <source>Error installing %1</source>
        <translation>Error al instalar %1</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="223"/>
        <source>Fix missing dependencies...</source>
        <translation>Corregir las dependencias que faltan....</translation>
    </message>
    <message>
        <source>Error running &apos;apt-get -fm install&apos; command</source>
        <translation type="vanished">Error al ejecutar el comando&apos;apt-get -fm install&apos;.</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="225"/>
        <source>Error running %1 command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="237"/>
        <source>&lt;b&gt;Installation process has finished&lt;/b&gt;</source>
        <translation>&lt;b&gt;La instalación ha finalizado&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="241"/>
        <source>Finished</source>
        <translation>El proceso ha terminado.</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="242"/>
        <source>Codecs files have been downloaded and installed successfully.</source>
        <translation>Los archivos de códec se han descargado e instalado con éxito.</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="246"/>
        <source>Process finished. Errors have occurred during the installation.</source>
        <translation>Proceso terminado. Ocurrieron errores durante la instalación.</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="260"/>
        <source>About MX Codecs</source>
        <translation>Acerca de MX Códecs</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="261"/>
        <source>MX Codecs</source>
        <translation>MX Códecs</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="261"/>
        <source>Version: </source>
        <translation>Versión:</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="263"/>
        <source>Simple codecs downloader for MX Linux</source>
        <translation>Gestor de descargas de códecs simple para MX Linux</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="264"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="265"/>
        <source>License</source>
        <translation>Licencia</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="266"/>
        <location filename="../mxcodecs.cpp" line="276"/>
        <source>Changelog</source>
        <translation>Registro de cambios</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="283"/>
        <source>&amp;Close</source>
        <translation>&amp;Close</translation>
    </message>
</context>
</TS>
